@@ -185,6 +185,7 @@ static const char* acceptable_fields[] = {
     "SourcesList",
     "AptHistoryLog",
     "AptTermLog",
+    "AptSolverDump",
     "DpkgLog",
     "SysLog",
     /* openjdk-8 */
@@ -824,6 +825,7 @@ process_existing_files (const char* report_dir)
     char* crash_file = NULL;
 
     dir = g_dir_open (report_dir, 0, NULL);
+    log_msg ("Looking for .upload files in %s\n", report_dir);
     while ((file = g_dir_read_name (dir)) != NULL) {
 
         upload_file = g_build_filename (report_dir, file, NULL);
@@ -842,7 +844,10 @@ process_existing_files (const char* report_dir)
             continue;
         }
 
+        log_msg ("Found .crash corresponding to .upload (%s)\n", crash_file);
+
         if (already_handled_report (crash_file)) {
+            log_msg ("Crash already uploaded, skipping\n");
             g_free (upload_file);
             g_free (crash_file);
             continue;
